@@ -316,7 +316,9 @@ def _file_exists(context, path):
 
         try:
             response = yield _head_object(context, context.s3_bucket, key)
+            
         except HTTPClientError as exception:
+            print('file_exit',exception.response)
             if exception.response.code != 404:
                 raise HTTPServerError(exception.response.code, 'Error checking if S3 exists')
             response = exception.response
@@ -828,12 +830,17 @@ def _head_object(context, bucket, key):
     credentials = yield context.s3_auth()
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
                              aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
-    response = yield s3_client.head_object(Bucket=bucket, Key=key)
-    print('head',response)
-    if 'ContentLength' in response and response['ContentLength'] >= 0:
-        return True
-    else:
-        return False
+    try:
+        response = yield s3_client.head_object(Bucket=bucket, Key=key)
+        print('head',response)
+        if 'ContentLength' in response and response['ContentLength'] >= 0:
+            return True
+        else:
+            return False
+    except ClientError as exc:
+        if exc.response['Error']['Code'] != '404':
+            raise
+
 
 @gen.coroutine
 def _put_object(context, bucket, body, object_name):
